RSAKeyData class

Inheritance

Constructors

RSAKeyData(List<int> modulus, List<int> exponent, KeySlot slot)
const
RSAKeyData.fromBytes(List<int> response, KeySlot slot)
factory

Properties

exponent → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
modulus → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slot → KeySlot
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJwk() → Jwk
inherited
toPublicKey() → PublicKey
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited