SmartCardError enum
Values
- doInTerminationState → const SmartCardError
- memoryFailure → const SmartCardError
- securityIssue → const SmartCardError
- wrongLength → const SmartCardError
- logicalChannelNotSupported → const SmartCardError
- secureMessagingNotSupported → const SmartCardError
- lastCommandOfChainExpected → const SmartCardError
- commandChainingNotSupported → const SmartCardError
- authenticationError → const SmartCardError
- authenticationBlocked → const SmartCardError
- conditionOfUseNotSatisfied → const SmartCardError
- expectedSecureMessagingDosMissing → const SmartCardError
- secureMessagingDosIncorrect → const SmartCardError
- incorrectParametersInCommandData → const SmartCardError
- fileOrApplicationNotFound → const SmartCardError
- referencedDataOrDoNotFound → const SmartCardError
- wrongParameters → const SmartCardError
- instructionCodeInvalid → const SmartCardError
- classNotSupported → const SmartCardError
- noPreciseDiagnosis → const SmartCardError
- unknown → const SmartCardError
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SmartCardError> - A constant List of the values in this enum, in order of their declaration.